#
# spec file for package python-blosc2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-blosc2
Version:        2.7.1
Release:        1.0.2.1.sr20241002
Summary:        Python wrapper for the C-Blosc2 library
License:        BSD-3-Clause
URL:            https://github.com/Blosc/python-blosc2
Source:         https://files.pythonhosted.org/packages/source/b/blosc2/blosc2-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.10}
BuildRequires:  %{python_module numpy-devel >= 1.20.3}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module scikit-build}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(blosc2) >= 2.14.4
Requires:       python-msgpack
Requires:       python-ndindex >= 1.4
Requires:       python-numexpr
Requires:       python-numpy >= 1.20.3
Requires:       python-py-cpuinfo
# SECTION test requirements
BuildRequires:  %{python_module msgpack}
BuildRequires:  %{python_module ndindex >= 1.4}
BuildRequires:  %{python_module numexpr}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module py-cpuinfo}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Blosc (https://blosc.org) is a high performance compressor optimized
for binary data. It has been designed to transmit data to the processor
cache faster than the traditional, non-compressed, direct memory fetch
approach via a memcpy() OS call.

Blosc works well for compressing numerical arrays that contains data
with relatively low entropy, like sparse data, time series, grids with
regular-spaced values, etc.

python-blosc2 is a Python package that wraps C-Blosc2, the newest version
of the Blosc compressor. Currently python-blosc2 already reproduces the
API of python-blosc, so the former can be used as a drop-in replacement
for the later.

%prep
%autosetup -p1 -n blosc2-%{version}

%build
export CFLAGS="%{optflags}"
export CPPFLAGS="%{optflags}"
# debundle c-blosc2
export SKBUILD_CONFIGURE_OPTIONS="-DUSE_SYSTEM_BLOSC2:BOOL=ON"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv blosc2 blosc2-src
donttest="dummyprefix"
%ifarch %ix86 %arm32
# too large for address memory
donttest="$donttest or (test_pack and int64)"
%endif
%pytest_arch -k "not ($donttest)"

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitearch}/blosc2
%{python_sitearch}/blosc2-%{version}.dist-info

%changelog
* Thu Oct 10 2024 Dirk Müller <dmueller@suse.com>
- update to 2.7.1:
  * Updated to latest C-Blosc2 2.15.1.
  * Fixes SIGKILL issues when using the `blosc2` library in old
    Intel CPUs.
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.7.0:
  * Updated to latest C-Blosc2 2.15.0.
  * Deprecated `LazyExpr.evaluate()`.
  * Fixed `_check_rc` function.
* Fri Apr 26 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.6.2
  * Protection when platforms have just one CPU. This caused the
    internal number of threads to be 0, producing a division by zero.
  * Updated to latest C-Blosc2 2.14.3.
- Release 2.6.0
  * [EXP] New evaluation engine (based on numexpr) for NDArray
    instances. Now, you can evaluate expressions like a + b + 1
    where a and b are NDArray instances. This is a powerful feature
    that allows for efficient computations on compressed data. See
    this example to see how this works. Thanks to @omaech for her
    help in the pow function.
  * As a consequence of the above, there are many new functions to
    operate with NDArray instances. See the function section in
    NDArray API for more information.
  * Support for NumPy 2.0.0 is here! Now, the wheels are built with
    NumPy 2.0.0rc1. Please tell us in case you see any issues with
    this new version.
  * Add **kwargs to load_tensor() function. This allows to pass
    additional parameters to the deserialization function. Thanks
    to @jasam-sheja.
  * Fix vlmeta.to_dict() not honoring tuple encoding. Thanks to
    @ivilata.
  * Check that chunks/blocks computation does not allow a 0 in
    blocks. Thanks to @ivilata.
  * Many improvements in ruff rules and others. Thanks to
    @DimitriPapadopoulos.
  * Remove printing large arrays in notebooks (they use too much
    RAM in recent versions of Jupyter notebook).
* Wed Feb  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.5.1
  * Updated to latest C-Blosc2 2.13.1.
  * Fixed bug in b2nd.h.
- Release 2.5.0
  * Updated to latest C-Blosc2 2.13.0.
  * Added the filter INT_TRUNC for integer truncation.
  * Added some optimizations for zstd.
  * Now the grok library is initialized when loading the plugin
    from C-Blosc2.
  * Improved doc.
  * Support for slices in blosc2.get_slice_nchunks() when using
    SChunk objects.
- Release 2.4.0
  * Updated to latest C-Blosc2 2.12.0.
  * Added blosc2.get_slice_nchunks() to get array of chunk indexes
    needed to get a slice of a Blosc2 container.
  * Added grok codec plugin.
  * Added imported target with pkg-config to support windows.
* Fri Dec  1 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.3.2
  * Support for `pathlib.Path` objects in all the places where
    `urlpath` is used (e.g. `blosc2.open()`). Thanks to Marta
    Iborra.
  * Included docs for `SChunk.fill_special()` and `NDArray.dtype`.
    Thanks to Francesc Alted.
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Temporarily disable AVX512 support in C-Blosc2 for wheels
    built by CI until run-time detection works properly.
  * Require at least Cython 3 for building. Using previous
    versions worked but error handling was not correct (wheels
    were being built with Cython 3 anyway).
  * New `NDArray.to_cframe()` method and
    `blosc2.ndarray_from_cframe()` function for serializing and
    deserializing NDArrays to/from contiguous in-memory frames.
    Thanks to Francesc Alted.
  * Add an optional `offset` argument to `blosc2.schunk.open()`,
    to access super-chunks stored in containers like HDF5. Thanks
    to Ivan Vilata.
  * Assorted minor fixes to the blocksize/blockshape computation
    algorithm, avoiding some cases where it resulted in values
    exceeding maximum limits. Thanks to Ivan Vilata.
  * Updated to latest C-Blosc2 2.11.2. It adds AVX512 support for
    the bitshuffle filter, fixes ARM and Raspberry Pi
    compatibility and assorted issues.
  * Add python-blosc2 package definition for Guix. Thanks to Ivan
    Vilata.
* Sat Oct 14 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.2.9
  * Support for specifying (plugable) tuner parameters in cparams. Thanks to
    Marta Iborra.
  * Re-add support for Python 3.8. Although we don't provide wheels for it,
    support is there (although it requires compilation time).
  * Avoid duplicate iteration over the same dict. Thanks to Dimitri Papadopoulos.
  * Fix different issues with f-strings. Thanks to Dimitri Papadopoulos.
- Release 2.2.8
  * Support for Python 3.12
  * Different improvements suggested by refurb and pyupgrade.
    Thanks to Dimitri Papadopoulos.
  * Updated to latest C-Blosc2 2.10.4.
* Mon Sep 18 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.7:
  * Updated to latest C-Blosc2 2.10.3.
  * Added openhtj2k codec plugin.
* Tue Aug 22 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.2.6
  * Multithreading checks only apply to Python defined codecs and
    filters. Now it is possible to use multithreading with C codecs
    and filters plugins. See PR #127.
  * New support for dynamic filters registry for Python.
  * Now params for codec and filter plugins are correctly
    initialized when using register_codec and register_filter
    functions.
  * Some fixes for Cython 3.0.0. However,compatibility with Cython
    3.0.0 is not here yet, so build and install scripts are still
    requiring Cython<3.
  * Updated to latest C-Blosc2 2.10.1.
- Release 2.2.5
  * Updated to latest C-Blosc2 2.10.0.
  * Use the new, fixed bytedelta filter introduced in C-Blosc2
    2.10.0.
  * Some small fixes in tutorials.
- Release 2.2.3 and 2.2.4
  * Added a new section of tutorials for a quick get start.
  * Added a new section on how to cite Blosc.
  * New method interchunks_info for SChunk and NDArray classes.
    This iterates through chunks for getting meta info, like
    decompression ratio, whether the chunk is special or not, among
    others. For more information on how this works see this
    example.
  * Now it is possible to register a dynamic plugin by passing None
    as the encoder and decoder arguments in the register_codec
    function.
  * Make shape of scalar slices NDArray objects to follow NumPy
    conventions. See #117.
  * Updated to latest C-Blosc2 2.9.3.
* Fri May 12 2023 Ben Greiner <code@bnavigator.de>
- Bump BuildRequires: Does not build with older c-blosc2
* Thu May 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.2.2
  * Changes relevant for wheels bundling c-blosc2 but not for linux
    packages using the library from system
- Update to 2.2.2
  * Updated to latest C-Blosc2 2.9.1.
* Tue Apr 25 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * New bytedelta filter.  We have blogged about this:
    https://www.blosc.org/posts/bytedelta-enhance-compression-
    toolset/.  See the examples/ndarray/bytedelta_filter.py for a
    sample script.  We also have a short video on how bytedelta
    works: https://www.youtube.com/watch?v=5OXs7w2x6nw
  * `dtype.itemsize` will have preference over typesize in
    cparams (as it was documented).
  * `blosc2.compressor_list(plugins=False)` do not list codec
    plugins by default now.  If you want to list plugins too, you
    need to pass `plugins=True`.
  * Internal C-Blosc2 updated to latest version (2.8.0).
* Thu Mar 30 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.1.1
  * New NDArray class for handling multidimensional arrays using
    compression. It includes:
  - Data type handling (fully compatible with NumPy)
  - Double partitioning
  * See examples at:
    https://github.com/Blosc/python-blosc2/tree/main/examples/ndarray
    NDarray docs at:
    https://www.blosc.org/python-blosc2/reference/ndarray_api.html
    Explanatory video on why double partitioning:
    https://youtu.be/LvP9zxMGBng Also, see our blog on C-Blosc2
    NDim counterpart:
    https://www.blosc.org/posts/blosc2-ndim-intro/
- Drop python-blosc2-pr92-debundle.patch
- Drop python-blosc2-pr82-fix-os-release.patch
* Fri Feb 24 2023 Ben Greiner <code@bnavigator.de>
- Skip incompatible tests on 32bit
* Fri Feb 17 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v2.0.0
- Add python-blosc2-pr92-debundle.patch
  * gh#Blosc/python-blosc2#92
  * Fixes gh#Blosc/python-blosc2#15
- Required by python-tables (PyTables)
